==> ShopMadeSimple0.3.2.zip: ShopMadeSimple/action.fe_product_detail.php <==
<?php

$gCms = cmsms(); if( !is_object($gCms) ) exit;

$detailpage = '';
if (isset($params['detailpage']))
{
	$manager = cmsms()->GetHierarchyManager();
	$node =& $manager->sureGetNodeByAlias($params['detailpage']);
	if (isset($node))
	{
		$content =& $node->GetContent();
		if (isset($content))
		{
			$detailpage = $content->Id();
		}
	}
	else
	{
		$node =& $manager->sureGetNodeById($params['detailpage']);
		if (isset($node))
		{
			$detailpage = $params['detailpage'];
		}
	}
}

$config = cmsms()->GetConfig();
$pathcat = $this->GetPreference('imagepath_category');
$pathproduct = $this->GetPreference('imagepath_product');
// Prepare settings for usage of cart
$cartMSInstalled = false;
$modulename = 'CartMadeSimple';

$cmsmodules = $gCms->modules;
if (isset($cmsmodules[$modulename]))
{
	if (isset($cmsmodules[$modulename]['object'])
		&& $cmsmodules[$modulename]['installed'] == true
		&& $cmsmodules[$modulename]['active'] == true ) {
		$cartMSInstalled = true;
	}
}

// Save the product id for correct usage throughout all queries
$product_id = '';
if (isset($params['product_id'])) $product_id = $params['product_id'];
$category_id = '';
if (isset($params['category_id'])) $category_id = $params['category_id'];

// Display information of the product
$query = "SELECT * FROM ".cms_db_prefix()."module_sms_products WHERE product_id = ?";
$row = $db->GetRow($query, array($product_id));

if ($row)
{
	$productprice = $row['price'];
	$quantityonstock = $row['maxattributes'];
	$this->smarty->assign('id', $product_id);
	$this->smarty->assign('productname', $row['name']);
	$this->smarty->assign('description', $row['description']);
	$this->smarty->assign('price', $row['price']);
	$this->smarty->assign('sku', $row['sku']);
	$this->smarty->assign('itemnumber', $row['itemnumber']);
	$this->smarty->assign('netweight', $row['netweight']);
	// Get the first picture available for the product found
	$query = "SELECT * FROM ".cms_db_prefix()."module_sms_product_images WHERE product_id = ?";
	$picture = $db->GetRow($query, array($product_id));
	if ($picture)
	{
		if (isset($picture['image']) && $picture['image'] != 'no_image.jpg') {
			$this->smarty->assign('prodimage', $pathproduct.$picture['image']);
			$this->smarty->assign('imagedesc', $row['description']);
		}
		else {
			$this->smarty->assign('prodimage', '*none');
		}
	}
	// When the {image} tag of smarty is not in use, the complete path must be passed
	$this->smarty->assign('pimage', $config['root_url'].DIRECTORY_SEPARATOR.'uploads'.
		DIRECTORY_SEPARATOR.'images'.$pathproduct.$picture['image']);
	// Build array that holds the images connected to the product
	$dbresult = $db->Execute($query, array($product_id));
	$entryarray = array();
	while ($dbresult && $row = $dbresult->FetchRow())
	{
		$onerow = new stdClass();
		if (isset($picture['image']) && $picture['image'] != 'no_image.jpg') {
			$onerow->image = $pathproduct.$row['image'];
			$onerow->imagethumb = $pathproduct.'tn_'.$row['image'];
			$onerow->imagedesc = $row['description'];
			$onerow->fullpathimage = $config['root_url'].DIRECTORY_SEPARATOR.'uploads'.
				DIRECTORY_SEPARATOR.'images'.$pathproduct.$row['image'];
		}

		$entryarray[] = $onerow;
	}
	$this->smarty->assign_by_ref('items', $entryarray);
	$this->smarty->assign('itemcount', count($entryarray));
	// Check if inventory in place. If so don't show any add to cart option
	$onstock = 'No';
	$inventorytype = $this->GetPreference('inventorytype');
	if ($inventorytype == 'prod' && $quantityonstock > 0) {
		$onstock = 'Yes';
	}
	if ($onstock == 'Yes') {
		// Build link to cart
		if ($cartMSInstalled) {
			$this->smarty->assign('addproduct', $cmsmodules[$modulename]['object']->CreateLink( $id, 'cart', $returnid, $this->Lang('addtocart'), 
				array ('name'=>$row['name'],
					'perfaction' => 'add_product',
					'category_id' => $category_id,
					'product_id' => $product_id,
					'qty' => 1,
					'returnmod' => 'ShopMadeSimple'
				)));
			$imagesrc = $this->ImageAddToCartSource();
			$this->smarty->assign('addproductimage', $cmsmodules[$modulename]['object']->CreateLink( $id, 'cart', 
				$returnid, '<img src="'.$imagesrc.'" alt="'.$this->Lang('addtocart').'" title="'.$this->Lang('addtocart').'">', 
				array ('name'=>$row['name'],
					'perfaction' => 'add_product',
					'category_id' => $category_id,
					'product_id' => $product_id,
					'qty' => 1,
					'returnmod' => 'ShopMadeSimple'
				)));
		}
	}

	$product_data = $this->products->Get($product_id);
	$attribute = array();
	$attributes = array();
	// Check if there are any attributes for the current product. If not checked, the foreach runs into an error
	$attributes['itemcount'] = count($product_data['attributes']);
	if ($attributes['itemcount'] > 0) {
		foreach ($product_data['attributes'] as $attribute) {
			if ($attribute['active']) {
				$attribute['name'] = $attribute['name'];
				$attribute['description'] = $attribute['description'];
				// Check if inventory in place. If so don't show any add to cart option
				$attribute['onstock'] = true;
				$inventorytype = $this->GetPreference('inventorytype');
				if (($inventorytype == 'attr' && $attribute['maxallowed'] > 0)
					|| $onstock == 'Yes') {
					$attribute['price'] = '';
					switch ($attribute['priceadjusttype']) {
						case 'P':
							$attribute['price'] = '+' . $this->FormatPrice($attribute['priceadjustment']);
							break;
						case 'M':
							$attribute['price'] = '-' . $this->FormatPrice($attribute['priceadjustment']);
							break;
						case 'T':
							$price = $this->CalculateAttributePrice($productprice, $attribute['priceadjusttype'], $attribute['priceadjustment']);
							$attribute['price'] = $this->FormatPrice($price);
							break;
						case 'V':
							$attribute['price'] = $this->FormatPrice($attribute['priceadjustment']);
							break;
					}
					if (!$attribute['displayonly']) {
						// Build link to cart
						if ($cartMSInstalled) {
							$attribute['addattribute'] = $cmsmodules[$modulename]['object']->CreateLink( $id, 
								'cart', $returnid, $this->Lang('addtocart'), array ('name'=>$row['name'],
									'perfaction' => 'add_product', 'category_id' => $category_id,
									'product_id' => $product_id, 'attribute_id' => $attribute['attribute_id'], 
									'qty' => 1, 'returnmod' => 'ShopMadeSimple'
								));
							$imagesrc = $this->ImageAddToCartSource();
							$attribute['addattributeimage'] = $cmsmodules[$modulename]['object']->CreateLink( $id, 'cart', 
								$returnid, '<img src="'.$imagesrc.'" alt="'.$this->Lang('addtocart').'" title="'.$this->Lang('addtocart').'">', 
								array ('name'=>$row['name'],
									'perfaction' => 'add_product', 'category_id' => $category_id,
									'product_id' => $product_id, 'attribute_id' => $attribute['attribute_id'], 
									'qty' => 1, 'returnmod' => 'ShopMadeSimple'
								));
						}
					}
				}
				else {
					$attribute['price'] = $this->Lang('productsoldout');
					$attribute['onstock'] = false;
					$attribute['addattribute'] = '';
				}
				$product_attributes_list[] = $attribute;
			}
		}
		$attributes['list'] = $product_attributes_list;
		// Now all the attributes are found, connect them for the front end
		$attributes['namecolumn'] = $this->Lang('column_attribute_name');
		$attributes['descriptioncolumn'] = $this->Lang('column_attribute_description');
		$attributes['pricecolumn'] = $this->Lang('column_attribute_price');
		$attributes['addattributecolumn'] = '';
		$this->smarty->assign_by_ref('attributes', $attributes);

	}
}

$cur_symbol = $this->GetPreference('default_symbol');
$this->smarty->assign('cur_symbol', $this->GetPreference('default_symbol'));

// Display template
$template = 'proddetail_template';
// Currently only one template available, so next lines will not perform anything
if (isset($params['proddetailtemplate'])) {
	$template = $params['proddetailtemplate'];
}
echo $this->ProcessTemplateFromDatabase($template);
?>

==> ShopMadeSimple-0.3.5.zip: ShopMadeSimple/action.fe_product_detail.php <==
<?php

$gCms = cmsms(); if( !is_object($gCms) ) exit;

$detailpage = '';
if (isset($params['detailpage']))
{
	$manager = cmsms()->GetHierarchyManager();
	$node =& $manager->sureGetNodeByAlias($params['detailpage']);
	if (isset($node))
	{
		$content =& $node->GetContent();
		if (isset($content))
		{
			$detailpage = $content->Id();
		}
	}
	else
	{
		$node =& $manager->sureGetNodeById($params['detailpage']);
		if (isset($node))
		{
			$detailpage = $params['detailpage'];
		}
	}
}

$config = cmsms()->GetConfig();
$pathcat = $this->GetPreference('imagepath_category');
$pathproduct = $this->GetPreference('imagepath_product');
// Prepare settings for usage of cart
$cartMSInstalled = false;
$modulename = 'CartMadeSimple';

$cmsmodules = $gCms->modules;
if (isset($cmsmodules[$modulename]))
{
	if (isset($cmsmodules[$modulename]['object'])
		&& $cmsmodules[$modulename]['installed'] == true
		&& $cmsmodules[$modulename]['active'] == true ) {
		$cartMSInstalled = true;
	}
}

// Save the product id for correct usage throughout all queries
$product_id = '';
if (isset($params['product_id'])) $product_id = $params['product_id'];
$category_id = '';
if (isset($params['category_id'])) $category_id = $params['category_id'];

// Display information of the product
$query = "SELECT * FROM ".cms_db_prefix()."module_sms_products WHERE product_id = ?";
$row = $db->GetRow($query, array($product_id));

if ($row)
{
	$productprice = $row['price'];
	$quantityonstock = $row['maxattributes'];
	$this->smarty->assign('id', $product_id);
	$this->smarty->assign('productname', $row['name']);
	$this->smarty->assign('description', $row['description']);
	$this->smarty->assign('price', $row['price']);
	$this->smarty->assign('sku', $row['sku']);
	$this->smarty->assign('itemnumber', $row['itemnumber']);
	$this->smarty->assign('netweight', $row['netweight']);
	// Get the first picture available for the product found
	$query = "SELECT * FROM ".cms_db_prefix()."module_sms_product_images WHERE product_id = ?";
	$picture = $db->GetRow($query, array($product_id));
	if ($picture)
	{
		if (isset($picture['image']) && $picture['image'] != 'no_image.jpg') {
			$this->smarty->assign('prodimage', $pathproduct.$picture['image']);
			$this->smarty->assign('imagedesc', $row['description']);
		}
		else {
			$this->smarty->assign('prodimage', '*none');
		}
	}
	// When the {image} tag of smarty is not in use, the complete path must be passed
	$this->smarty->assign('pimage', $config['root_url'].DIRECTORY_SEPARATOR.'uploads'.
		DIRECTORY_SEPARATOR.'images'.$pathproduct.$picture['image']);
	// Build array that holds the images connected to the product
	$dbresult = $db->Execute($query, array($product_id));
	$entryarray = array();
	while ($dbresult && $row = $dbresult->FetchRow())
	{
		$onerow = new stdClass();
		if (isset($picture['image']) && $picture['image'] != 'no_image.jpg') {
			$onerow->image = $pathproduct.$row['image'];
			$onerow->imagethumb = $pathproduct.'tn_'.$row['image'];
			$onerow->imagedesc = $row['description'];
			$onerow->fullpathimage = $config['root_url'].DIRECTORY_SEPARATOR.'uploads'.
				DIRECTORY_SEPARATOR.'images'.$pathproduct.$row['image'];
		}

		$entryarray[] = $onerow;
	}
	$this->smarty->assign_by_ref('items', $entryarray);
	$this->smarty->assign('itemcount', count($entryarray));
	// Check if inventory in place. If so don't show any add to cart option
	$onstock = 'No';
	$inventorytype = $this->GetPreference('inventorytype');
	if ($inventorytype == 'prod' && $quantityonstock > 0 || $inventorytype == 'none') {
		$onstock = 'Yes';
	}
	if ($onstock == 'Yes') {
		// Build link to cart
		if ($cartMSInstalled) {
			$this->smarty->assign('addproduct', $cmsmodules[$modulename]['object']->CreateLink( $id, 'cart', $returnid, $this->Lang('addtocart'), 
				array ('name'=>$row['name'],
					'perfaction' => 'add_product',
					'category_id' => $category_id,
					'product_id' => $product_id,
					'qty' => 1,
					'returnmod' => 'ShopMadeSimple'
				)));
			$imagesrc = $this->ImageAddToCartSource();
			$this->smarty->assign('addproductimage', $cmsmodules[$modulename]['object']->CreateLink( $id, 'cart', 
				$returnid, '<img src="'.$imagesrc.'" alt="'.$this->Lang('addtocart').'" title="'.$this->Lang('addtocart').'">', 
				array ('name'=>$row['name'],
					'perfaction' => 'add_product',
					'category_id' => $category_id,
					'product_id' => $product_id,
					'qty' => 1,
					'returnmod' => 'ShopMadeSimple'
				)));
		}
	}

	$product_data = $this->products->Get($product_id);
	$attribute = array();
	$attributes = array();
	// Check if there are any attributes for the current product. If not checked, the foreach runs into an error
	$attributes['itemcount'] = count($product_data['attributes']);
	if ($attributes['itemcount'] > 0) {
		foreach ($product_data['attributes'] as $attribute) {
			if ($attribute['active']) {
				$attribute['name'] = $attribute['name'];
				$attribute['description'] = $attribute['description'];
				// Check if inventory in place. If so don't show any add to cart option
				$attribute['onstock'] = true;
				$inventorytype = $this->GetPreference('inventorytype');
				if (($inventorytype == 'attr' && $attribute['maxallowed'] > 0)
					|| $onstock == 'Yes') {
					$attribute['price'] = '';
					$price = $this->CalculateAttributePrice($productprice, $attribute['priceadjusttype'], $attribute['priceadjustment']);
					$attribute['price'] = $this->FormatPrice($price);
					if (!$attribute['displayonly']) {
						// Build link to cart
						if ($cartMSInstalled) {
							$attribute['addattribute'] = $cmsmodules[$modulename]['object']->CreateLink( $id, 
								'cart', $returnid, $this->Lang('addtocart'), array ('name'=>$row['name'],
									'perfaction' => 'add_product', 'category_id' => $category_id,
									'product_id' => $product_id, 'attribute_id' => $attribute['attribute_id'], 
									'qty' => 1, 'returnmod' => 'ShopMadeSimple'
								));
							$imagesrc = $this->ImageAddToCartSource();
							$attribute['addattributeimage'] = $cmsmodules[$modulename]['object']->CreateLink( $id, 'cart', 
								$returnid, '<img src="'.$imagesrc.'" alt="'.$this->Lang('addtocart').'" title="'.$this->Lang('addtocart').'">', 
								array ('name'=>$row['name'],
									'perfaction' => 'add_product', 'category_id' => $category_id,
									'product_id' => $product_id, 'attribute_id' => $attribute['attribute_id'], 
									'qty' => 1, 'returnmod' => 'ShopMadeSimple'
								));
						}
					}
				}
				else {
					$attribute['price'] = $this->Lang('productsoldout');
					$attribute['onstock'] = false;
					$attribute['addattribute'] = '';
				}
				$product_attributes_list[] = $attribute;
			}
		}
		$attributes['list'] = $product_attributes_list;
		// Now all the attributes are found, connect them for the front end
		$attributes['namecolumn'] = $this->Lang('column_attribute_name');
		$attributes['descriptioncolumn'] = $this->Lang('column_attribute_description');
		$attributes['pricecolumn'] = $this->Lang('column_attribute_price');
		$attributes['addattributecolumn'] = '';
		$this->smarty->assign_by_ref('attributes', $attributes);

	}
}

$cur_symbol = $this->GetPreference('default_symbol');
$this->smarty->assign('cur_symbol', $this->GetPreference('default_symbol'));

// Display template
$template = 'proddetail_template';
// Currently only one template available, so next lines will not perform anything
if (isset($params['proddetailtemplate'])) {
	$template = $params['proddetailtemplate'];
}
echo $this->ProcessTemplateFromDatabase($template);
?>
